/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright held by original author
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    concentrationFvPatchScalarField

Description
    Boundary condition specifies a logarithmic velocity inlet profile
    (fixed value), given maximum velocity value (peak of the parabola),
    flow direction n and direction of the logarithmic coordinate y

SourceFiles
    concentrationFvPatchScalarField.C

Author
    Hrvoje Jasak, Wikki Ltd.  All rights reserved

\*---------------------------------------------------------------------------*/

#ifndef concentrationFvPatchScalarField_H
#define concentrationFvPatchScalarField_H

#include "fvPatchFields.H"
#include "fixedValueFvPatchFields.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
              Class concentrationFvPatchField Declaration
\*---------------------------------------------------------------------------*/

class concentrationFvPatchScalarField
:
    public fixedValueFvPatchScalarField
{
    // Private data

        //- Velocity magnitude 1
        scalar Vel1_;

	//- Velocity magnitude 2
	scalar Vel2_;

	//- Height 1
	scalar h1_;

	//- Height 2
	scalar h2_;

        //- Flow direction
        scalar n_;

        //- Direction of the y-coordinate
        scalar y_;

	//- Concentration Reference height
	scalar href_;

        //- Reference concentration
        scalar cref_;
public:

    //- Runtime type information
    TypeName("concentration");


    // Constructors

        //- Construct from patch and internal field
        concentrationFvPatchScalarField
        (
            const fvPatch&,
            const DimensionedField<scalar, volMesh>&
        );

        //- Construct from patch, internal field and dictionary
        concentrationFvPatchScalarField
        (
            const fvPatch&,
            const DimensionedField<scalar, volMesh>&,
            const dictionary&
        );

        //- Construct by mapping given concentrationFvPatchScalarField
        //  onto a new patch
        concentrationFvPatchScalarField
        (
            const concentrationFvPatchScalarField&,
            const fvPatch&,
            const DimensionedField<scalar, volMesh>&,
            const fvPatchFieldMapper&
        );

        //- Construct and return a clone
        virtual tmp<fvPatchScalarField> clone() const
        {
            return tmp<fvPatchScalarField>
            (
                new concentrationFvPatchScalarField(*this)
            );
        }

        //- Construct as copy setting internal field reference
        concentrationFvPatchScalarField
        (
            const concentrationFvPatchScalarField&,
            const DimensionedField<scalar, volMesh>&
        );

        //- Construct and return a clone setting internal field reference
        virtual tmp<fvPatchScalarField> clone
        (
            const DimensionedField<scalar, volMesh>& iF
        ) const
        {
            return tmp<fvPatchScalarField>
            (
                new concentrationFvPatchScalarField(*this, iF)
            );
        }


    // Member functions

        //- Return Vel1 value
        scalar& Vel1()
        {
            return Vel1_;
        }

	//- Return Vel2 value
	scalar& Vel2()
	{
	   return Vel2_;
	}

	//- Return h1 value
	scalar& h1()
	{
	   return h1_;
	}
	
	//- Return h2 value
	scalar& h2()
	{
	   return h2_;
	}

        //- Return flow direction
        scalar& n()
        {
            return n_;
        }

        //- Return y direction
        scalar& y()
        {
            return y_;
        }

	 //- Return concentration reference height
	 scalar href()
	 {
	    return href_;
	 }

        //- Return reference concentration value
        scalar cref()
        {
            return cref_;
        }

        //- Update coefficients
        virtual void updateCoeffs();

        //- Write
        virtual void write(Ostream&) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
